@@ -1,7 +1,6 @@
 use super::*;
 
-// TODO: need Copy?
-#[derive(Copy, Clone, PartialEq, PartialOrd, Eq, Ord)]
+#[derive(Clone)]
 pub struct AssemblyRef(pub Row);
 
 impl std::fmt::Debug for AssemblyRef {
